// Set up the formulas for zooming, if applicable
function zoomFormulas() {
	var error = "<div class='formulaError'>This formula is too large to be displayed on your mobile device. Try again <span class='portraitOnly'>in landscape or </span>on a larger device.</div>";
	var formulas = document.querySelectorAll('.formulaContainer');

	// Clean up formulas with errors because we will be re-processing them
	var formulaErrors = document.querySelectorAll('.formulaError');
	[].forEach.call(formulaErrors, function(formulaError,i) {
		formulaError.parentNode.className = 'formulaContainer';
		formulaError.parentNode.childNodes[0].style.webkitTransform="";
		formulaError.parentNode.childNodes[0].style.transform="";
		formulaError.parentNode.style.height="";
		formulaError.parentNode.style.width="";
		formulaError.parentNode.style.float='';
		formulaError.parentNode.removeChild(formulaError);
	});

	// Process each formula and resize them if necessary
	[].forEach.call(formulas, function(formula,i) {
		var outerGraphicWidth = formula.offsetWidth;
		var innerGraphicWidth = formula.childNodes[0].childNodes[0].offsetWidth;
		var innerGraphicHeight = formula.childNodes[0].childNodes[0].offsetHeight;

		var scaleAmt = (outerGraphicWidth / innerGraphicWidth);

		// Maximum scale size for formulas - 1 = the same size as the topic text
		if (scaleAmt > 1) {
			scaleAmt = 1;
		}

		// Minimum scale size for formulas - should be about when formulas are too small to read
		// If formula falls below minimum, display an error message instead of the formula
		if (scaleAmt < 0.5) {
			formula.className = 'formulaContainer formulaHasError';
			formula.innerHTML += error;
			return false;
		}

		// Apply the calculated scale to the formula
		// Use scale3d to force hardware GPU rendering to improve performance
		formula.childNodes[0].style.webkitTransform="scale3d(" + scaleAmt + "," + scaleAmt + ",1)";
		formula.childNodes[0].style.transform="scale3d(" + scaleAmt + "," + scaleAmt + ",1)";
		formula.style.height=(innerGraphicHeight*scaleAmt)+"px";
		formula.style.width="100%";
		formula.style.float='left';
	});
}

//zoomFormulas();
//window.resize(function(){
//	zoomFormulas();
//});